package
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: Jul 8, 2025
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Option func(constant *Text)
Option represents an option that can be used to configure a textbox variable.
Hide ensures that the variable will not be displayed.
HideLabel ensures that this variable's label will not be displayed.
Label sets the label of the variable.
type Text struct {
Builder sdk.TemplateVar
}
Text represents a "textbox" templated variable.
New creates a new "query" templated variable.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.