Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Matcher ¶
type Matcher func(field *sdk.FieldConfigOverride)
type OverrideOption ¶
type OverrideOption func(field *sdk.FieldConfigOverride)
func AxisPlacement ¶
func AxisPlacement(placement axis.PlacementMode) OverrideOption
AxisPlacement overrides how the axis should be placed in the panel.
func FixedColorScheme ¶
func FixedColorScheme(color string) OverrideOption
FixedColorScheme forces the use of a fixed color scheme.
func NegativeY ¶
func NegativeY() OverrideOption
NegativeY flips the results to negative values on the Y axis.
func Stack ¶
func Stack(mode StackMode) OverrideOption
Stack overrides if the series should be stacked and using which mode (default not stacked).
Click to show internal directories.
Click to hide internal directories.